@@ -171,7 +171,7 @@ dmap_av_share_server_info (DmapShare * share,
 	g_object_get ((gpointer) share, "name", &nameprop, NULL);
 
 	msrv = dmap_structure_add (NULL, DMAP_CC_MSRV);
-	dmap_structure_add (msrv, DMAP_CC_MSTT, (gint32) DMAP_STATUS_OK);
+	dmap_structure_add (msrv, DMAP_CC_MSTT, (gint32) SOUP_STATUS_OK);
 	dmap_structure_add (msrv, DMAP_CC_MPRO, (gdouble) DAAP_VERSION);
 	dmap_structure_add (msrv, DMAP_CC_APRO, (gdouble) DAAP_VERSION);
 	/* 2/3 is for itunes 4.8 (at least).  its determined by the
@@ -203,8 +203,7 @@ dmap_av_share_server_info (DmapShare * share,
 	g_free (nameprop);
 }
 
-typedef enum
-{
+typedef enum {
 	ITEM_ID = 0,
 	ITEM_NAME,
 	ITEM_KIND,
@@ -303,7 +302,8 @@ static struct DmapMetaDataMap _meta_data_map[] = {
 #define DAAP_SONG_DATA_KIND_NONE 0
 
 static gboolean
-_should_transcode (const gchar *format,
+_should_transcode (DmapAvShare *share,
+                   const gchar *format,
                    const gboolean has_video,
                    const gchar *transcode_mimetype)
 {
@@ -321,7 +321,8 @@ _should_transcode (const gchar *format,
 
 	format2 = dmap_utils_mime_to_format (transcode_mimetype);
 	if (NULL == format2) {
-		g_warning ("Configured to transcode, but target format is bad");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_BAD_FORMAT,
+		                     "Configured to transcode, but target format bad");
 		goto done;
 	}
 
@@ -338,7 +339,7 @@ done:
 }
 
 static void
-_send_chunked_file (SoupServer * server, SoupMessage * message,
+_send_chunked_file (DmapAvShare *share, SoupServer * server, SoupMessage * message,
 		   DmapAvRecord * record, guint64 filesize, guint64 offset,
 		   const gchar * transcode_mimetype)
 {
@@ -354,7 +355,8 @@ _send_chunked_file (SoupServer * server, SoupMessage * message,
 
 	g_object_get (record, "location", &location, "has-video", &has_video, NULL);
 	if (NULL == location) {
-		g_warning ("Error getting location from record\n");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_RECORD_MISSING_FIELD,
+		                     "Error getting location from record");
 		goto done;
 	}
 
@@ -366,23 +368,27 @@ _send_chunked_file (SoupServer * server, SoupMessage * message,
 
 	stream = G_INPUT_STREAM (dmap_av_record_read (record, &error));
 	if (error != NULL) {
-		g_warning ("Couldn't open %s: %s.", location, error->message);
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_OPEN_FAILED,
+		                     "Cannot open %s", error->message);
 		goto done;
 	}
 
 	g_object_get (record, "format", &format, NULL);
 	if (NULL == format) {
-		g_warning ("Error getting format from record\n");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_RECORD_MISSING_FIELD,
+		                     "Error getting format from record");
 		goto done;
 	}
 
 	// Not presently transcoding videos (see also same comments elsewhere).
-	if (_should_transcode (format, has_video, transcode_mimetype)) {
+	if (_should_transcode (share, format, has_video, transcode_mimetype)) {
 #ifdef HAVE_GSTREAMERAPP
 		cd->original_stream = stream;
 		cd->stream = dmap_gst_input_stream_new (transcode_mimetype, stream);
 #else
-		g_warning ("Transcode format %s not supported", transcode_mimetype);
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_BAD_FORMAT,
+		                     "Transcode format %s not supported",
+		                      transcode_mimetype);
 		cd->original_stream = NULL;
 		cd->stream = stream;
 #endif /* HAVE_GSTREAMERAPP */
@@ -393,13 +399,15 @@ _send_chunked_file (SoupServer * server, SoupMessage * message,
 	}
 
 	if (cd->stream == NULL) {
-		g_warning ("Could not set up input stream");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_OPEN_FAILED,
+		                     "Could not setup input stream");
 		goto done;
 	}
 
 	if (offset != 0) {
 		if (g_seekable_seek (G_SEEKABLE (cd->stream), offset, G_SEEK_SET, NULL, &error) == FALSE) {
-			g_warning ("Error seeking: %s.", error->message);
+			dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_SEEK_FAILED,
+			                     "Error seeking: %s.", error->message);
 			goto done;
 		}
 		filesize -= offset;
@@ -408,7 +416,7 @@ _send_chunked_file (SoupServer * server, SoupMessage * message,
 	/* Free memory after each chunk sent out over network. */
 	soup_message_body_set_accumulate (message->response_body, FALSE);
 
-	if (! _should_transcode (format, has_video, transcode_mimetype)) {
+	if (! _should_transcode (share, format, has_video, transcode_mimetype)) {
 	        /* NOTE: iTunes seems to require this or it stops reading
 	         * video data after about 2.5MB. Perhaps this is so iTunes
 	         * knows how much data to buffer.
@@ -441,19 +449,22 @@ _send_chunked_file (SoupServer * server, SoupMessage * message,
 
 	if (0 == g_signal_connect (message, "wrote_headers",
 			           G_CALLBACK (dmap_private_utils_write_next_chunk), cd)) {
-		g_warning ("Error connecting to wrote_headers signal.");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_FAILED,
+		                     "Error connecting to wrote_headers signal");
 		goto done;
 	}
 
 	if (0 == g_signal_connect (message, "wrote_chunk",
 			  G_CALLBACK (dmap_private_utils_write_next_chunk), cd)) {
-		g_warning ("Error connecting to wrote_chunk signal.");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_FAILED,
+		                     "Error connecting to wrote_chunk signal");
 		goto done;
 	}
 
 	if (0 == g_signal_connect (message, "finished",
 			  G_CALLBACK (dmap_private_utils_chunked_message_finished), cd)) {
-		g_warning ("Error connecting to finished signal.");
+		dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_FAILED,
+		                     "Error connecting to finished signal");
 		goto done;
 	}
 	/* NOTE: cd g_free'd by chunked_message_finished(). */
@@ -469,14 +480,20 @@ done:
 		if (NULL != cd && NULL != cd->stream) {
 			ok = g_input_stream_close (cd->stream, NULL, &error);
 			if (!ok) {
-				g_warning ("Error closing transcode stream: %s.", error->message);
+				dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_CLOSE_FAILED,
+				                     "Error closing transcode stream: %s.",
+				                      error->message);
 			}
 		}
 
+		g_clear_error(&error);
+
 		if (NULL != stream) {
 			ok = g_input_stream_close (stream, NULL, &error);
 			if (!ok) {
-				g_warning ("Error closing stream: %s.", error->message);
+				dmap_share_emit_error(DMAP_SHARE(share), DMAP_STATUS_CLOSE_FAILED,
+				                     "Error closing stream: %s.",
+				                      error->message);
 			}
 		}
 
@@ -488,7 +505,7 @@ done:
 	g_free (format);
 
 	if (NULL != error) {
-		g_error_free (error);
+		g_error_free(error);
 	}
 
 	return;
@@ -758,7 +775,7 @@ _add_entry_to_mlcl (guint id, DmapRecord * record, gpointer _mb)
 }
 
 static void
-_genre_tabulator (gpointer id, DmapRecord * record, GHashTable * ht)
+_genre_tabulator (gpointer id, DmapRecord *record, GHashTable *ht)
 {
 	const gchar *genre;
 
@@ -877,13 +894,14 @@ _databases_browse_xxx (DmapShare * share,
 				      category_items);
 		category_cc = DMAP_CC_ABAL;
 	} else {
-		g_warning ("Unsupported browse category: %s",
-			   browse_category);
+		dmap_share_emit_error(share, DMAP_STATUS_BAD_BROWSE_CATEGORY,
+		                     "Unsupported browse category: %s",
+		                      browse_category);
 		goto _bad_category;
 	}
 
 	abro = dmap_structure_add (NULL, DMAP_CC_ABRO);
-	dmap_structure_add (abro, DMAP_CC_MSTT, (gint32) DMAP_STATUS_OK);
+	dmap_structure_add (abro, DMAP_CC_MSTT, (gint32) SOUP_STATUS_OK);
 	dmap_structure_add (abro, DMAP_CC_MUTY, 0);
 
 	num_genre = g_hash_table_size (category_items);
@@ -919,7 +937,8 @@ _databases_items_xxx (DmapShare * share,
                       const char *path,
                       GHashTable * query, SoupClientContext * context)
 {
-	DmapDb *db;
+	DmapDb *db = NULL;
+	DmapAvRecord *record = NULL;
 	gchar *transcode_mimetype = NULL;
 	const gchar *rest_of_path;
 	const gchar *id_str;
@@ -927,14 +946,23 @@ _databases_items_xxx (DmapShare * share,
 	const gchar *range_header;
 	guint64 filesize;
 	guint64 offset = 0;
-	DmapAvRecord *record;
 
 	rest_of_path = strchr (path + 1, '/');
 	id_str = rest_of_path + 9;
 	id = strtoul (id_str, NULL, 10);
 
 	g_object_get (share, "db", &db, NULL);
+
 	record = DMAP_AV_RECORD (dmap_db_lookup_by_id (db, id));
+	if (NULL == record) {
+		g_signal_emit_by_name(share, "error",
+			g_error_new(DMAP_ERROR,
+			            DMAP_STATUS_DB_BAD_ID,
+			           "Bad record identifier requested"));
+		soup_message_set_status (msg, SOUP_STATUS_NOT_FOUND);
+		goto done;
+	}
+
 	g_object_get (record, "filesize", &filesize, NULL);
 
 	DMAP_SHARE_GET_CLASS (share)->message_add_standard_headers
@@ -970,11 +998,18 @@ _databases_items_xxx (DmapShare * share,
 		soup_message_set_status (msg, SOUP_STATUS_OK);
 	}
 	g_object_get (share, "transcode-mimetype", &transcode_mimetype, NULL);
-	_send_chunked_file (server, msg, record, filesize, offset,
-			   transcode_mimetype);
+	_send_chunked_file (DMAP_AV_SHARE(share), server, msg, record, filesize,
+	                    offset, transcode_mimetype);
+
+done:
+	if (NULL != record) {
+		g_object_unref (record);
+	}
+
+	if (NULL != db) {
+		g_object_unref (db);
+	}
 
-	g_object_unref (record);
-	g_object_unref (db);
 	g_free(transcode_mimetype);
 }
 
@@ -1020,7 +1055,7 @@ _build_share_test(char *name)
 	g_object_set(record, "location", "file:///etc/services", NULL);
 	g_object_set(record, "filesize", statbuf.st_size, NULL);
 
-	dmap_db_add(db, record);
+	dmap_db_add(db, record, NULL);
 
 	if (-1 == stat("/etc/group", &statbuf)) {
 		ck_abort();
@@ -1032,7 +1067,8 @@ _build_share_test(char *name)
 	g_object_set(record, "songalbum", "album2", NULL);
 	g_object_set(record, "location", "file:///etc/group", NULL);
 	g_object_set(record, "filesize", statbuf.st_size, NULL);
-	dmap_db_add(db, record);
+
+	dmap_db_add(db, record, NULL);
 
 	share  = DMAP_SHARE(dmap_av_share_new(name,
 	                                   NULL,
@@ -1072,7 +1108,7 @@ START_TEST(dmap_av_share_new_test)
 	g_object_set(record, "songartist", "artist1", NULL);
 	g_object_set(record, "songalbum", "album1", NULL);
 
-	dmap_db_add(db, record);
+	dmap_db_add(db, record, NULL);
 
 	share = DMAP_SHARE(dmap_av_share_new("name",
 	                                     "password",
@@ -1118,7 +1154,7 @@ START_TEST(dmap_av_share_serve_publish_test)
 	g_object_set(record, "songartist", "artist1", NULL);
 	g_object_set(record, "songalbum", "album1", NULL);
 
-	dmap_db_add(db, record);
+	dmap_db_add(db, record, NULL);
 
 	share = DMAP_SHARE(dmap_av_share_new("name",
 	                                     "password",
@@ -1126,10 +1162,10 @@ START_TEST(dmap_av_share_serve_publish_test)
 	                                      container_db,
 	                                     "audio/mp3"));
 
-	ok = dmap_share_serve(share);
+	ok = dmap_share_serve(share, NULL);
 	ck_assert(ok);
 
-	ok = dmap_share_publish(share);
+	ok = dmap_share_publish(share, NULL);
 	ck_assert(ok);
 
 	g_object_unref(db);
@@ -1158,7 +1194,7 @@ START_TEST(dmap_av_share_serve_publish_collision_test)
 	g_object_set(record, "songartist", "artist1", NULL);
 	g_object_set(record, "songalbum", "album1", NULL);
 
-	dmap_db_add(db, record);
+	dmap_db_add(db, record, NULL);
 
 	share1 = DMAP_SHARE(dmap_av_share_new("name",
 	                                      "password",
@@ -1166,10 +1202,10 @@ START_TEST(dmap_av_share_serve_publish_collision_test)
 	                                       container_db,
 	                                      "audio/mp3"));
 
-	ok = dmap_share_serve(share1);
+	ok = dmap_share_serve(share1, NULL);
 	ck_assert(ok);
 
-	ok = dmap_share_publish(share1);
+	ok = dmap_share_publish(share1, NULL);
 	ck_assert(ok);
 
 	share2 = DMAP_SHARE(dmap_av_share_new("name",
@@ -1178,10 +1214,10 @@ START_TEST(dmap_av_share_serve_publish_collision_test)
 	                                       container_db,
 	                                      "audio/mp3"));
 
-	ok = dmap_share_serve(share2);
+	ok = dmap_share_serve(share2, NULL);
 	ck_assert(ok);
 
-	ok = dmap_share_publish(share2);
+	ok = dmap_share_publish(share2, NULL);
 	ck_assert(ok);
 
 	g_object_unref(db);
@@ -1207,12 +1243,12 @@ _tabulator_test(char *property,
 	record1 = DMAP_RECORD(test_dmap_av_record_new());
 	g_object_set(record1, property, "str1", NULL);
 
-	id1 = dmap_db_add(db, record1);
+	id1 = dmap_db_add(db, record1, NULL);
 
 	record2 = DMAP_RECORD(test_dmap_av_record_new());
 	g_object_set(record2, property, "str2", NULL);
 
-	id2 = dmap_db_add(db, record2);
+	id2 = dmap_db_add(db, record2, NULL);
 
 	ht = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -1249,45 +1285,81 @@ START_TEST(_album_tabulator_test)
 }
 END_TEST
 
-START_TEST(_should_transcode_test)
+static int _status = DMAP_STATUS_OK;
+
+static void
+_error_cb(DmapShare *share, GError *error, gpointer user_data)
 {
-	ck_assert_int_eq(FALSE, _should_transcode("mp3", TRUE, "audio/wav"));
+	_status = error->code;
+}
+
+START_TEST(_should_transcode_test_no)
+{
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(FALSE, _should_transcode(share, "mp3", TRUE, "audio/wav"));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_no_trancode_mimetype)
 {
-	ck_assert_int_eq(FALSE, _should_transcode("foo", FALSE, NULL));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(FALSE, _should_transcode(share, "foo", FALSE, NULL));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_no_trancode_mimetype_unknown_mimetype)
 {
-	ck_assert_int_eq(FALSE, _should_transcode("mp3", FALSE, "foo"));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(FALSE, _should_transcode(share, "mp3", FALSE, "foo"));
+	ck_assert_int_eq(DMAP_STATUS_BAD_FORMAT, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_no_trancode_mimetype_already_good)
 {
-	ck_assert_int_eq(FALSE, _should_transcode("mp3", FALSE, "audio/mp3"));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(FALSE, _should_transcode(share, "mp3", FALSE, "audio/mp3"));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_yes_trancode_mimetype_to_wav)
 {
-	ck_assert_int_eq(TRUE, _should_transcode("mp3", FALSE, "audio/wav"));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(TRUE, _should_transcode(share, "mp3", FALSE, "audio/wav"));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_yes_trancode_mimetype_to_mp3)
 {
-	ck_assert_int_eq(TRUE, _should_transcode("wav", FALSE, "audio/mp3"));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(TRUE, _should_transcode(share, "wav", FALSE, "audio/mp3"));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
 START_TEST(_should_transcode_test_yes_trancode_mimetype_to_mp4)
 {
-	ck_assert_int_eq(TRUE, _should_transcode("wav", FALSE, "video/quicktime"));
+	_status = DMAP_STATUS_OK;
+	DmapAvShare *share = dmap_av_share_new("test", NULL, NULL, NULL, NULL);
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
+	ck_assert_int_eq(TRUE, _should_transcode(share, "wav", FALSE, "video/quicktime"));
+	ck_assert_int_eq(DMAP_STATUS_OK, _status);
 }
 END_TEST
 
@@ -1333,10 +1405,10 @@ START_TEST(dmap_av_share_server_info_test)
 	buffer = soup_message_body_flatten(body);
 	soup_buffer_get_data(buffer, &data, &length);
 
-	root = dmap_structure_parse(data, length);
+	root = dmap_structure_parse(data, length, NULL);
 
 	item = dmap_structure_find_item(root, DMAP_CC_MSTT);
-	ck_assert_int_eq(DMAP_STATUS_OK, item->content.data->v_int);
+	ck_assert_int_eq(SOUP_STATUS_OK, item->content.data->v_int);
 
 	item = dmap_structure_find_item(root, DMAP_CC_MPRO);
 	ck_assert_int_eq(DAAP_VERSION, item->content.data->v_double);
@@ -1438,10 +1510,10 @@ START_TEST(_databases_browse_xxx_test)
 	buffer = soup_message_body_flatten(body);
 	soup_buffer_get_data(buffer, &data, &length);
 
-	root = dmap_structure_parse(data, length);
+	root = dmap_structure_parse(data, length, NULL);
 
 	item = dmap_structure_find_item(root, DMAP_CC_MSTT);
-	ck_assert_int_eq(DMAP_STATUS_OK, item->content.data->v_int);
+	ck_assert_int_eq(SOUP_STATUS_OK, item->content.data->v_int);
 
 	item = dmap_structure_find_item(root, DMAP_CC_MUTY);
 	ck_assert_int_eq(0, item->content.data->v_int);
@@ -1494,7 +1566,7 @@ START_TEST(_databases_browse_xxx_artists_test)
 	buffer = soup_message_body_flatten(body);
 	soup_buffer_get_data(buffer, &data, &length);
 
-	root = dmap_structure_parse(data, length);
+	root = dmap_structure_parse(data, length, NULL);
 
 	root = dmap_structure_find_node(root, DMAP_CC_MLIT);
 	ck_assert(NULL != root);
@@ -1535,7 +1607,7 @@ START_TEST(_databases_browse_xxx_albums_test)
 	buffer = soup_message_body_flatten(body);
 	soup_buffer_get_data(buffer, &data, &length);
 
-	root = dmap_structure_parse(data, length);
+	root = dmap_structure_parse(data, length, NULL);
 
 	root = dmap_structure_find_node(root, DMAP_CC_MLIT);
 	ck_assert(NULL != root);
@@ -1576,7 +1648,7 @@ START_TEST(_databases_browse_xxx_bad_category_test)
 	buffer = soup_message_body_flatten(body);
 	soup_buffer_get_data(buffer, &data, &length);
 
-	root = dmap_structure_parse(data, length);
+	root = dmap_structure_parse(data, length, NULL);
 	ck_assert(NULL == root);
 
 	g_object_unref(share);
@@ -1664,7 +1736,11 @@ START_TEST(_databases_items_xxx_test_bad_id)
 
 	/* IDs go from G_MAXINT down, so 0 does not exist. */
 	g_snprintf(path, sizeof path, "/db/1/items/%d", 0);
+
+	_status = DMAP_STATUS_OK;
+	g_signal_connect(share, "error", G_CALLBACK(_error_cb), NULL);
 	_databases_items_xxx(share, server, message, path, NULL, NULL);
+	ck_assert_int_eq(DMAP_STATUS_DB_BAD_ID, _status);
 
 	g_object_unref(share);
 }
