@@ -17,10 +17,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA*
  */
 
-#ifndef __DMAP_CONFIG_H__
-#define __DMAP_CONFIG_H__
+#ifndef _DMAP_CONFIG_H
+#define _DMAP_CONFIG_H
 
 /* whether or not the CPU supports unaligned access */
-#define DMAP_HAVE_UNALIGNED_ACCESS 0
+#define DMAP_HAVE_UNALIGNED_ACCESS 1
 
 #endif
