@@ -98,13 +98,13 @@ test_dmap_image_record_set_property (GObject *object,
 			if (record->priv->thumbnail) {
 				g_array_unref(record->priv->thumbnail);
 			}
-                        record->priv->thumbnail = g_value_dup_boxed (value);
+                        record->priv->thumbnail = g_value_get_boxed (value);
                         break;
                 case PROP_HASH:
 			if (record->priv->hash) {
 				g_array_unref(record->priv->hash);
 			}
-                        record->priv->hash= g_value_dup_boxed (value);
+                        record->priv->hash = g_value_get_boxed (value);
                         break;
                 case PROP_COMMENTS:
 			g_free (record->priv->comments);
